# Quality Tools

**Dependencies**

Assumes Teradata >=17.20.

**Data Quality** tools:

- qlty_missingValues - returns a list of column names with missing values
- qlty_negativeValues - returns a list of column names with negative values
- qlty_distinctCategories - returns a list of categories within a column
- qlty_standardDeviation - returns the mean and standard deviation for a column
- qlty_columnSummary - returns the column summary statistics for a table
- qlty_univariateStatistics - returns the univariate statistics for a table
- qlty_rowsWithMissingValues - returns rows with missing values in a table


**Data Quality** prompts:
- qlty_databaseQuality - perform a data quality assess across a database and return a quality dashboard

[Return to Main README](../../../../README.md)
